This function print result of function mcm.mvt, mmcm.mvt and mmcm.resamp
# S3 method for mmcm
print(x, digits = getOption("digits"), ...)Object of class mmcm, which is result of function mcm.mvt, mmcm.mvt and mmcm.resamp.
a non-null value for digits specifies the minimum number of significant digits to be printed in values. The default, NULL, uses getOption(digits). (For the interpretation for complex numbers see signif.) Non-integer values will be rounded down, and only values greater than or equal to 1 and no greater than 22 are accepted.
Further arguments passed to or from other methods.
The case where printed "More than 2 contrast coefficient vectors were selected", some contrast may be unsuitable.